Module config

Module config 

Types and utilities for configuring a Tailscale Device.

Structs

Config
Config for connecting to Tailscale.

Enums

BadFormatBehavior
What to do if the key file can’t be parsed.

Functions

auth_key_from_env
Load an auth key from the TS_AUTH_KEY environment variable.
load_key_file
Load key state from a path on the filesystem, or create a file with a new key state if one doesn’t exist.