pub enum Error {
Timeout,
ConnectionReset,
KeyFileRead,
KeyFileWrite,
UnstableEnvVar,
Internal(InternalErrorKind),
}Expand description
Errors that may occur while interacting with a device.
Variants
Timeout
An operation timed-out.
This error can often be handled by retrying.
ConnectionReset
A connection was reset.
This error can often be handled by retrying.
KeyFileRead
An error reading or parsing the key file.
KeyFileWrite
An error writing out the key file.
UnstableEnvVar
The environment variable TS_RS_EXPERIMENT was not set.
The end-user must set TS_RS_EXPERIMENT=this_is_unstable_software to acknowledge that tailscale-rs
is early-days experimental software containing bugs, unvalidated cryptography, and no stability
or compatibility guarantees.
Internal(InternalErrorKind)
An error occurred which can not be anticipated or handled by a library user.
This is likely due to a bug in our code or a rare and unexpected error.
InternalErrorKind is intended to be informational (might be used to improve error reporting
in logs or to the end-user), rather then inspected during handling.