Module keys

Module keys 

Tailscale cryptographic key types.

Structs

DiscoKeyPair
The X25519 public/private key pair a Tailscale node uses for the Disco protocol.
DiscoPrivateKey
The X25519 private key a Tailscale node uses for the Disco protocol.
DiscoPublicKey
The X25519 public key a Tailscale node uses for the Disco protocol.
MachineKeyPair
The X25519 public/private key pair of a unique piece of hardware running one or more Tailscale nodes.
MachinePrivateKey
The X25519 private key of a unique piece of hardware running one or more Tailscale nodes.
MachinePublicKey
The X25519 public key of a unique piece of hardware running one or more Tailscale nodes. Also the key type sent from a control server to a Tailscale node during the initial control handshake.
NetworkLockKeyPair
The X25519 public/private key pair of a Tailscale node for use with Tailnet Lock.
NetworkLockPrivateKey
The X25519 private key of a Tailscale node for use with Tailnet Lock.
NetworkLockPublicKey
The X25519 public key of a Tailscale node for use with Tailnet Lock.
NodeKeyPair
The X25519 public/private key pair of a Tailscale node.
NodePrivateKey
The X25519 private key of a Tailscale node.
NodePublicKey
The X25519 public key of a Tailscale node.
NodeState
The complete runtime key state for a Tailscale node.
PersistState
The portion of the key state that should be retained between runs of the same device.