pub struct DiscoPrivateKey(/* private fields */);Expand description
The X25519 private key a Tailscale node uses for the Disco protocol.
Implementations
Sourceimpl DiscoPrivateKey
impl DiscoPrivateKey
Sourcepub const KEY_LEN_BYTES: usize = 32
pub const KEY_LEN_BYTES: usize = 32
The length of this key type, in bytes.
Sourcepub const KEY_LEN_HEX_STR: usize
pub const KEY_LEN_HEX_STR: usize
The length of a hexidecimal string representation of this key, excluding the prefix and colon.
Sourcepub const KEY_LEN_FULL_STR: usize
pub const KEY_LEN_FULL_STR: usize
The length of a hexidecimal string representation of this key, including the prefix and colon.
Sourcepub const KEY_PREFIX: &'static str = "privkey"
pub const KEY_PREFIX: &'static str = "privkey"
The prefix placed in front of string representations of this key type, such as “$key_prefix:abcd…”
Sourceimpl DiscoPrivateKey
impl DiscoPrivateKey
Sourcepub fn random() -> DiscoPrivateKey
pub fn random() -> DiscoPrivateKey
Generate a new X25519 private key.
Sourcepub fn public_key(self) -> DiscoPublicKey
pub fn public_key(self) -> DiscoPublicKey
Calculate the corresponding public key for this private key.