NetworkLockPrivateKey

Struct NetworkLockPrivateKey 

pub struct NetworkLockPrivateKey(/* private fields */);
The Ed25519 private key of a Tailscale node for use with Tailnet Lock.

Implementations

Source

impl NetworkLockPrivateKey

pub const KEY_LEN_BYTES: usize = 32

The length of this key type, in bytes.

pub const KEY_LEN_HEX_STR: usize

The length of a hexidecimal string representation of this key, excluding the prefix and colon.

pub const KEY_LEN_FULL_STR: usize

The length of a hexidecimal string representation of this key, including the prefix and colon.

pub const KEY_PREFIX: &'static str = "nlpriv"

The prefix placed in front of string representations of this key type, such as “$key_prefix:abcd…”

pub fn to_bytes(&self) -> [u8; 32]

Return this key as a u8 byte array.

Source

impl NetworkLockPrivateKey

pub fn random() -> NetworkLockPrivateKey

Generate a new Ed25519 private key.

Sources 32 uniformly-random bytes for the Ed25519 seed directly from getrandom. We deliberately do NOT reuse x25519_dalek::StaticSecret, whose bytes are bit clamped (low bits zeroed, bit 254 set); clamping reduces seed entropy and is wrong for an Ed25519 seed.

pub fn public_key(self) -> NetworkLockPublicKey

Calculate the corresponding public key for this private key.

This is the standard RFC 8032 seed->public derivation, matching Go’s ed25519.PrivateKey.Public().

pub fn signing_key(&self) -> SigningKey

Return this key as an ed25519_dalek::SigningKey, treating the wrapped bytes as the Ed25519 seed (RFC 8032).