pub struct NetworkLockPublicKey(/* private fields */);Expand description
The Ed25519 public key of a Tailscale node for use with Tailnet Lock.
Implementations
Sourceimpl NetworkLockPublicKey
impl NetworkLockPublicKey
Sourcepub const KEY_LEN_BYTES: usize = 32
pub const KEY_LEN_BYTES: usize = 32
The length of this key type, in bytes.
Sourcepub const KEY_LEN_HEX_STR: usize
pub const KEY_LEN_HEX_STR: usize
The length of a hexidecimal string representation of this key, excluding the prefix and colon.
Sourcepub const KEY_LEN_FULL_STR: usize
pub const KEY_LEN_FULL_STR: usize
The length of a hexidecimal string representation of this key, including the prefix and colon.
Sourcepub const KEY_PREFIX: &'static str = "nlpub"
pub const KEY_PREFIX: &'static str = "nlpub"
The prefix placed in front of string representations of this key type, such as “$key_prefix:abcd…”