pub struct NodePublicKey(/* private fields */);Expand description
The X25519 public key of a Tailscale node.
Implementations
Sourceimpl NodePublicKey
impl NodePublicKey
Sourcepub const KEY_LEN_BYTES: usize = 32
pub const KEY_LEN_BYTES: usize = 32
The length of this key type, in bytes.
Sourcepub const KEY_LEN_HEX_STR: usize
pub const KEY_LEN_HEX_STR: usize
The length of a hexidecimal string representation of this key, excluding the prefix and colon.
Sourcepub const KEY_LEN_FULL_STR: usize
pub const KEY_LEN_FULL_STR: usize
The length of a hexidecimal string representation of this key, including the prefix and colon.
Sourcepub const KEY_PREFIX: &'static str = "nodekey"
pub const KEY_PREFIX: &'static str = "nodekey"
The prefix placed in front of string representations of this key type, such as “$key_prefix:abcd…”