pub enum Error {
BadRequest(BadRequestReason),
Internal(InternalErrorKind),
ConnectionReset,
}Expand description
Error while interacting with the netstack.
Variants
BadRequest(BadRequestReason)
The request contained invalid parameters. Retrying will not resolve this issue.
Common causes for this error are that a specified address was invalid, there is not enough memory available in the current configuration to complete the request, or the packet to be sent was too large for the socket’s buffer capacity.
Internal(InternalErrorKind)
An internal error occurred.
These errors are either unrecoverable, due to a bug in our code, or caused by a rare and intermittent issue.
ConnectionReset
A TCP connection was reset.
These errors can often be handled by retrying.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn wrong_type() -> Error
pub fn wrong_type() -> Error
Error constructor for the wrong type of command response.
Sourcepub fn invalid_socket_state() -> Error
pub fn invalid_socket_state() -> Error
Error constructor for an invalid socket state.
Sourcepub fn missing_listener() -> Error
pub fn missing_listener() -> Error
Error constructor for a missing TCP listener.
Sourcepub fn missing_socket() -> Error
pub fn missing_socket() -> Error
Error constructor for a missing socket.
Sourcepub fn big_packet() -> Error
pub fn big_packet() -> Error
Error constructor for an over-size packet.
Sourcepub fn buffer_full() -> Error
pub fn buffer_full() -> Error
Error constructor for out-of-memory (likely in a specific component, rather than a system OOM).
Sourcepub fn unaddressable() -> Error
pub fn unaddressable() -> Error
Error constructor for an unaddressable packet.
Sourcepub fn zero_buffer() -> Error
pub fn zero_buffer() -> Error
Error constructor for a zero-sized buffer.