pub struct SshRecorderFailureAction {
pub reject_session_with_message: String,
pub terminate_session_with_message: String,
pub notify_url: String,
}Expand description
What to do when session recording fails for an SshAction that has recorders configured.
Mirrors tailcfg.SSHRecorderFailureAction.
Fields
reject_session_with_message: StringIf non-empty, refuse the session with this message when recording cannot start. This is
Go’s explicit fail-closed signal (RejectSessionWithMessage).
terminate_session_with_message: StringIf non-empty, terminate an in-progress session with this message when recording fails.
notify_url: StringIf non-empty, a URL to notify out-of-band when recording fails.