TailnetServer

Trait TailnetServer 

pub trait TailnetServer {
    // Required method
    fn new_client(dev: Arc<Device>, addr: SocketAddr) -> Self;
}
Trait to construct a new Handler from a Tailscale Device and the address of a connecting client.

Rephrasing of russh::server::Server that includes the Tailscale device as an argument and skips the support for off-tailnet IP and Unix sockets.

Required Methods

fn new_client(dev: Arc<Device>, addr: SocketAddr) -> Self

Construct a new handler.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors