pub struct Config {
pub key_state: PersistState,
pub client_name: Option<String>,
pub control_server_url: Url,
pub requested_hostname: Option<String>,
pub requested_tags: Vec<String>,
}Expand description
Config for connecting to Tailscale.
Fields
key_state: PersistStateThe cryptographic keys representing this node’s identity.
client_name: Option<String>The name of this client.
This is reported to control in the Hostinfo.App field.
control_server_url: UrlThe URL of the control server to connect to.
requested_hostname: Option<String>The hostname this node will request.
If left blank, uses the hostname reported by the OS.
Tags this node will request.
Implementations
Sourceimpl Config
impl Config
Sourcepub async fn default_with_key_file(p: impl AsRef<Path>) -> Result<Self, Error>
pub async fn default_with_key_file(p: impl AsRef<Path>) -> Result<Self, Error>
Create a new config with its key_state populated from the specified key file and using
default options for other configuration.
See load_key_file for more details and an alternative with more options for reading
the key file.
Sourcepub fn default_from_env() -> Config
pub fn default_from_env() -> Config
Construct a default config, setting certain fields from environment variables.
The fields are only set if the corresponding environment variable is present, using the default value otherwise.
Loads:
control_server_urlfromTS_CONTROL_URLrequested_hostnamefromTS_HOSTNAME