pub struct NodeInfo {Show 17 fields
pub id: i64,
pub stable_id: StableId,
pub hostname: String,
pub capability_version: CapabilityVersion,
pub status: NodeStatus,
pub tailnet: Option<String>,
pub node_capabilities: BTreeMap<String, Vec<String>>,
pub tags: Vec<String>,
pub tailnet_address: TailnetAddress,
pub node_key: NodePublicKey,
pub node_key_expiry: Option<DateTime<Utc>>,
pub machine_key: Option<MachinePublicKey>,
pub disco_key: Option<DiscoPublicKey>,
pub tailnet_lock_key_signature: Option<Vec<u8>>,
pub accepted_routes: Vec<IpNet>,
pub underlay_addresses: Vec<SocketAddr>,
pub derp_region: Option<RegionId>,
}Expand description
A node in a tailnet.
Fields
id: i64The node’s id.
stable_id: StableIdThe node’s stable id.
hostname: StringThe node’s hostname.
capability_version: CapabilityVersionThe node’s capability version.
status: NodeStatusWhether the node is connected to the control plane or not. If NodeStatus::Unknown, the
control plane hasn’t told us yet.
This field does not indicate whether the node is reachable or visible from this device.
tailnet: Option<String>The tailnet this node belongs to.
node_capabilities: BTreeMap<String, Vec<String>>The node capabilities assigned to this node.
The tags assigned to this node.
tailnet_address: TailnetAddressThe address of the node in the tailnet.
node_key: NodePublicKeyThe node’s NodePublicKey.
node_key_expiry: Option<DateTime<Utc>>The node key’s expiration.
machine_key: Option<MachinePublicKey>The node’s MachinePublicKey, if known.
disco_key: Option<DiscoPublicKey>The node’s DiscoPublicKey, if known.
tailnet_lock_key_signature: Option<Vec<u8>>The signature of the node’s public key with the Tailnet Lock signing key, if Tailnet Lock is enabled and the signature is known.
accepted_routes: Vec<IpNet>The routes this node accepts traffic for.
underlay_addresses: Vec<SocketAddr>The underlay addresses this node is reachable on (Endpoints in Go).
derp_region: Option<RegionId>The DERP region for this node, if known.
Implementations
Sourceimpl Node
impl Node
Sourcepub fn apply_update(&mut self, update: &NodeUpdate)
pub fn apply_update(&mut self, update: &NodeUpdate)
Apply the given partial update to this Node.
Panics
If update.id does not match self.id. The caller must guarantee this method is only
called with NodeUpdates for this Node.
Sourcepub fn fqdn(&self, trailing_dot: bool) -> String
pub fn fqdn(&self, trailing_dot: bool) -> String
The fully-qualified domain name of the node.
This is a string of the form $HOST.$TAILNET_DOMAIN.. For tailnets controlled by
Tailscale’s control plane, this usually means $HOST.tail1234.ts.net.
The trailing_dot parameter specifies whether to include the trailing dot in the
fqdn. This is included by the definition of FQDN, and is the way the Go codebase
formats this field, but the parameter is included to allow turning it off for use
in contexts that expect it to be absent.
Sourcepub fn fqdn_opt(&self, trailing_dot: bool) -> Option<String>
pub fn fqdn_opt(&self, trailing_dot: bool) -> Option<String>
The fully-qualified domain name of the node, only returning Some if the tailnet
component is present.
See Node::fqdn.
Sourcepub fn matches_name(&self, name: &str) -> bool
pub fn matches_name(&self, name: &str) -> bool
Report whether this node matches the given name.
name is checked for equality with both this node’s bare hostname and its fqdn. A
trailing . may be present.