Types and utilities for configuring a Tailscale Device.
Structs
- Config
- Config for connecting to Tailscale.
Enums
- BadFormat
Behavior - What to do if the key file can’t be parsed.
Functions
- auth_
key_ from_ env - Load an auth key from the
TS_AUTH_KEYenvironment variable. - load_
key_ file - Load key state from a path on the filesystem, or create a file with a new key state if one doesn’t exist.