Error

Enum Error 

pub enum Error {
    InternalFailure,
    RuntimeDegraded,
    Timeout,
    ConnectionReset,
}
Errors that may occur while interacting with a device.

Variants



InternalFailure

Internal operation failed, likely a bug.



RuntimeDegraded

The runtime state was degraded: a component that we expected to be able to communicate with hung up or could not be reached.

This usually means that an internal component has panicked or is wedged.



Timeout

An operation timed out.



ConnectionReset

A connection was reset.