Tailscale cryptographic key types.
Structs
- Disco
KeyPair - The X25519 public/private key pair a Tailscale node uses for the Disco protocol.
- Disco
Private Key - The X25519 private key a Tailscale node uses for the Disco protocol.
- Disco
Public Key - The X25519 public key a Tailscale node uses for the Disco protocol.
- Machine
KeyPair - The X25519 public/private key pair of a unique piece of hardware running one or more Tailscale nodes.
- Machine
Private Key - The X25519 private key of a unique piece of hardware running one or more Tailscale nodes.
- Machine
Public Key - The X25519 public key of a unique piece of hardware running one or more Tailscale nodes. Also the key type sent from a control server to a Tailscale node during the initial control handshake.
- Network
Lock KeyPair - The X25519 public/private key pair of a Tailscale node for use with Tailnet Lock.
- Network
Lock Private Key - The X25519 private key of a Tailscale node for use with Tailnet Lock.
- Network
Lock Public Key - The X25519 public key of a Tailscale node for use with Tailnet Lock.
- Node
KeyPair - The X25519 public/private key pair of a Tailscale node.
- Node
Private Key - The X25519 private key of a Tailscale node.
- Node
Public Key - The X25519 public key of a Tailscale node.
- Node
State - The complete runtime key state for a Tailscale node.
- Persist
State - The portion of the key state that should be retained between runs of the same device.