pub struct MachinePublicKey(/* private fields */);Expand description
The X25519 public key of a unique piece of hardware running one or more Tailscale nodes. Also the key type sent from a control server to a Tailscale node during the initial control handshake.
Implementations
Sourceimpl MachinePublicKey
impl MachinePublicKey
Sourcepub const KEY_LEN_BYTES: usize = 32
pub const KEY_LEN_BYTES: usize = 32
The length of this key type, in bytes.
Sourcepub const KEY_LEN_HEX_STR: usize
pub const KEY_LEN_HEX_STR: usize
The length of a hexidecimal string representation of this key, excluding the prefix and colon.
Sourcepub const KEY_LEN_FULL_STR: usize
pub const KEY_LEN_FULL_STR: usize
The length of a hexidecimal string representation of this key, including the prefix and colon.
Sourcepub const KEY_PREFIX: &'static str = "mkey"
pub const KEY_PREFIX: &'static str = "mkey"
The prefix placed in front of string representations of this key type, such as “$key_prefix:abcd…”