pub struct Config {
pub key_state: NodeState,
pub client_name: Option<String>,
pub control_server_url: Url,
pub requested_hostname: Option<String>,
pub requested_tags: Vec<String>,
}Expand description
Config for connecting to Tailscale.
Fields
key_state: NodeStateThe path of the file used to store cryptographic keys.
This file represents this node’s identity. The key file format is specific to
tailscale-rs; key files are not interchangeable with those produced by other
implementations of Tailscale, e.g. tailscaled or tsnet.
client_name: Option<String>The name of this client.
This is reported to control in the Hostinfo.App field.
control_server_url: UrlThe URL of the control server to connect to.
requested_hostname: Option<String>The hostname this node will request.
If left blank, uses the hostname reported by the OS.
Tags this node will request.