pub struct Device { /* private fields */ }Expand description
Tailscale client.
Implementations
Sourceimpl Device
impl Device
Sourcepub fn udp_bind<'p>(
&self,
py: Python<'p>,
addr: (IpRepr, u16),
) -> PyResult<Bound<'p, PyAny>>
pub fn udp_bind<'p>( &self, py: Python<'p>, addr: (IpRepr, u16), ) -> PyResult<Bound<'p, PyAny>>
Bind a new UDP socket on the given addr.
addr must be given as (host, port). Presently, host must be an IP.
Sourcepub fn tcp_listen<'p>(
&self,
py: Python<'p>,
addr: (IpRepr, u16),
) -> PyResult<Bound<'p, PyAny>>
pub fn tcp_listen<'p>( &self, py: Python<'p>, addr: (IpRepr, u16), ) -> PyResult<Bound<'p, PyAny>>
Bind a new TCP listen socket on the given addr and port.
addr must be given as (host, port). Presently, host must be an IP.
Sourcepub fn tcp_connect<'p>(
&self,
py: Python<'p>,
addr: (IpRepr, u16),
) -> PyResult<Bound<'p, PyAny>>
pub fn tcp_connect<'p>( &self, py: Python<'p>, addr: (IpRepr, u16), ) -> PyResult<Bound<'p, PyAny>>
Create a new TCP connection to the given addr.
addr must be given as (host, port). Presently, host must be an IP.
Sourcepub fn ipv4_addr<'p>(&self, py: Python<'p>) -> PyResult<Bound<'p, PyAny>>
pub fn ipv4_addr<'p>(&self, py: Python<'p>) -> PyResult<Bound<'p, PyAny>>
Get the device’s IPv4 tailnet address.
Sourcepub fn ipv6_addr<'p>(&self, py: Python<'p>) -> PyResult<Bound<'p, PyAny>>
pub fn ipv6_addr<'p>(&self, py: Python<'p>) -> PyResult<Bound<'p, PyAny>>
Get the device’s IPv6 tailnet address.
Sourcepub fn peer_by_name<'p>(
&self,
py: Python<'p>,
name: String,
) -> PyResult<Bound<'p, PyAny>>
pub fn peer_by_name<'p>( &self, py: Python<'p>, name: String, ) -> PyResult<Bound<'p, PyAny>>
Look up info about a peer by its name.
name may be an unqualified hostname or a fully-qualified name.
Sourcepub fn self_node<'p>(&self, py: Python<'p>) -> PyResult<Bound<'p, PyAny>>
pub fn self_node<'p>(&self, py: Python<'p>) -> PyResult<Bound<'p, PyAny>>
Get this device’s node info.