Device

Struct Device 

pub struct Device { /* private fields */ }
Tailscale client.

Implementations

Source

impl Device

pub fn udp_bind<'p>( &self, py: Python<'p>, addr: (IpRepr, u16), ) -> PyResult<Bound<'p, PyAny>>

Bind a new UDP socket on the given addr.

addr must be given as (host, port). Presently, host must be an IP.

pub fn tcp_listen<'p>( &self, py: Python<'p>, addr: (IpRepr, u16), ) -> PyResult<Bound<'p, PyAny>>

Bind a new TCP listen socket on the given addr and port.

addr must be given as (host, port). Presently, host must be an IP.

pub fn tcp_connect<'p>( &self, py: Python<'p>, addr: (IpRepr, u16), ) -> PyResult<Bound<'p, PyAny>>

Create a new TCP connection to the given addr.

addr must be given as (host, port). Presently, host must be an IP.

pub fn ipv4_addr<'p>(&self, py: Python<'p>) -> PyResult<Bound<'p, PyAny>>

Get the device’s IPv4 tailnet address.

pub fn ipv6_addr<'p>(&self, py: Python<'p>) -> PyResult<Bound<'p, PyAny>>

Get the device’s IPv6 tailnet address.

pub fn peer_by_name<'p>( &self, py: Python<'p>, name: String, ) -> PyResult<Bound<'p, PyAny>>

Look up info about a peer by its name.

name may be an unqualified hostname or a fully-qualified name.