NodeInfo

Struct NodeInfo 

pub struct NodeInfo {
Show 13 fields pub id: i64, pub stable_id: StableId, pub hostname: String, pub tailnet: Option<String>, pub tags: Vec<String>, pub tailnet_address: TailnetAddress, pub node_key: NodePublicKey, pub node_key_expiry: Option<DateTime<Utc>>, pub machine_key: Option<MachinePublicKey>, pub disco_key: Option<DiscoPublicKey>, pub accepted_routes: Vec<IpNet>, pub underlay_addresses: Vec<SocketAddr>, pub derp_region: Option<RegionId>,
}
A node in a tailnet.

Fields

id: i64

The node’s id.

stable_id: StableId

The node’s stable id.

hostname: String

This node’s hostname.

tailnet: Option<String>

The tailnet this node belongs to.

tags: Vec<String>

The tags assigned to this node.

tailnet_address: TailnetAddress

The address of the node in the tailnet.

node_key: NodePublicKey

The node’s NodePublicKey.

node_key_expiry: Option<DateTime<Utc>>

The node key’s expiration.

machine_key: Option<MachinePublicKey>

The node’s MachinePublicKey, if known.

disco_key: Option<DiscoPublicKey>

The node’s DiscoPublicKey, if known.

accepted_routes: Vec<IpNet>

The routes this node accepts traffic for.

underlay_addresses: Vec<SocketAddr>

The underlay addresses this node is reachable on (Endpoints in Go).

derp_region: Option<RegionId>

The DERP region for this node, if known.

Implementations

Source

impl Node

pub fn fqdn(&self, trailing_dot: bool) -> String

The fully-qualified domain name of the node.

This is a string of the form $HOST.$TAILNET_DOMAIN.. For tailnets controlled by Tailscale’s control plane, this usually means $HOST.tail1234.ts.net.

The trailing_dot parameter specifies whether to include the trailing dot in the fqdn. This is included by the definition of FQDN, and is the way the Go codebase formats this field, but the parameter is included to allow turning it off for use in contexts that expect it to be absent.

pub fn matches_name(&self, name: &str) -> bool

Report whether this node matches the given name.

name is checked for equality with both this node’s bare hostname and its fqdn. A trailing . may be present.