pub type ConfigureHook = Box<dyn Fn(&mut Config) + Send + Sync>;Expand description
A hook to customize the derived Config after the field mapping and before the device is
built — the escape hatch to fork capabilities with no Go tsnet field. See Server::configure.
Aliased Type
pub struct ConfigureHook(/* private fields */);